@@ -580,24 +580,10 @@ openfortivpn_watch_cb (GPid pid, gint status, gpointer user_data)
 	waitpid (priv->pid, NULL, WNOHANG);
 	priv->pid = 0;
 
-	/* Must be after data->state is set since signals use data->state */
-	switch (error) {
-	case 16:
-		/* hangup */
-		// FIXME: better failure reason
-		nm_vpn_plugin_failure (NM_VPN_PLUGIN (plugin), NM_VPN_PLUGIN_FAILURE_CONNECT_FAILED);
-		break;
-	case 2:
-		/* Couldn't log in due to bad user/pass */
-		nm_vpn_plugin_failure (NM_VPN_PLUGIN (plugin), NM_VPN_PLUGIN_FAILURE_LOGIN_FAILED);
-		break;
-	case 1:
-		/* Other error (couldn't bind to address, etc) */
-		nm_vpn_plugin_failure (NM_VPN_PLUGIN (plugin), NM_VPN_PLUGIN_FAILURE_CONNECT_FAILED);
-		break;
-	default:
-		break;
-	}
+	/* TODO: Better error indication from openfortivpn. */
+	if (error)
+		nm_vpn_plugin_failure (NM_VPN_PLUGIN (plugin),
+		                       NM_VPN_PLUGIN_FAILURE_CONNECT_FAILED);
 
 	nm_vpn_plugin_set_state (NM_VPN_PLUGIN (plugin), NM_VPN_SERVICE_STATE_STOPPED);
 	cleanup_plugin (plugin);
@@ -694,7 +680,7 @@ run_openfortivpn (NMFortisslvpnPlugin *plugin, NMSettingVPN *s_vpn, GError **err
 		g_ptr_array_add (argv, (gpointer) g_strdup (value));
 	}
 
-	g_ptr_array_add (argv, (gpointer) g_strdup ("--plugin"));
+	g_ptr_array_add (argv, (gpointer) g_strdup ("--pppd-plugin"));
 	g_ptr_array_add (argv, (gpointer) g_strdup (NM_FORTISSLVPN_PPPD_PLUGIN));
 
 	g_ptr_array_add (argv, NULL);
